==> istio-model-v1alpha3-6.6.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPRouteFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Double;
import java.util.Collection;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import java.util.Iterator;
import java.lang.Integer;

 /**
  * Generated
  */
public interface HTTPRouteFluent<A extends HTTPRouteFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCorsPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public CorsPolicy getCorsPolicy();
  public CorsPolicy buildCorsPolicy();
  public A withCorsPolicy(CorsPolicy corsPolicy);
  public Boolean hasCorsPolicy();
  public HTTPRouteFluent.CorsPolicyNested<A> withNewCorsPolicy();
  public HTTPRouteFluent.CorsPolicyNested<A> withNewCorsPolicyLike(CorsPolicy item);
  public HTTPRouteFluent.CorsPolicyNested<A> editCorsPolicy();
  public HTTPRouteFluent.CorsPolicyNested<A> editOrNewCorsPolicy();
  public HTTPRouteFluent.CorsPolicyNested<A> editOrNewCorsPolicyLike(CorsPolicy item);
  
  /**
   * This method has been deprecated, please use method buildDelegate instead.
   * @return The buildable object.
   */
  @Deprecated
  public Delegate getDelegate();
  public Delegate buildDelegate();
  public A withDelegate(Delegate delegate);
  public Boolean hasDelegate();
  public A withNewDelegate(String name,String namespace);
  public HTTPRouteFluent.DelegateNested<A> withNewDelegate();
  public HTTPRouteFluent.DelegateNested<A> withNewDelegateLike(Delegate item);
  public HTTPRouteFluent.DelegateNested<A> editDelegate();
  public HTTPRouteFluent.DelegateNested<A> editOrNewDelegate();
  public HTTPRouteFluent.DelegateNested<A> editOrNewDelegateLike(Delegate item);
  
  /**
   * This method has been deprecated, please use method buildFault instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPFaultInjection getFault();
  public HTTPFaultInjection buildFault();
  public A withFault(HTTPFaultInjection fault);
  public Boolean hasFault();
  public HTTPRouteFluent.FaultNested<A> withNewFault();
  public HTTPRouteFluent.FaultNested<A> withNewFaultLike(HTTPFaultInjection item);
  public HTTPRouteFluent.FaultNested<A> editFault();
  public HTTPRouteFluent.FaultNested<A> editOrNewFault();
  public HTTPRouteFluent.FaultNested<A> editOrNewFaultLike(HTTPFaultInjection item);
  
  /**
   * This method has been deprecated, please use method buildHeaders instead.
   * @return The buildable object.
   */
  @Deprecated
  public Headers getHeaders();
  public Headers buildHeaders();
  public A withHeaders(Headers headers);
  public Boolean hasHeaders();
  public HTTPRouteFluent.HeadersNested<A> withNewHeaders();
  public HTTPRouteFluent.HeadersNested<A> withNewHeadersLike(Headers item);
  public HTTPRouteFluent.HeadersNested<A> editHeaders();
  public HTTPRouteFluent.HeadersNested<A> editOrNewHeaders();
  public HTTPRouteFluent.HeadersNested<A> editOrNewHeadersLike(Headers item);
  public A addToMatch(Integer index,HTTPMatchRequest item);
  public A setToMatch(Integer index,HTTPMatchRequest item);
  public A addToMatch(io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequest... items);
  public A addAllToMatch(Collection<HTTPMatchRequest> items);
  public A removeFromMatch(io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequest... items);
  public A removeAllFromMatch(Collection<HTTPMatchRequest> items);
  public A removeMatchingFromMatch(Predicate<HTTPMatchRequestBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMatch instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPMatchRequest> getMatch();
  public List<HTTPMatchRequest> buildMatch();
  public HTTPMatchRequest buildMatch(Integer index);
  public HTTPMatchRequest buildFirstMatch();
  public HTTPMatchRequest buildLastMatch();
  public HTTPMatchRequest buildMatchingMatch(Predicate<HTTPMatchRequestBuilder> predicate);
  public Boolean hasMatchingMatch(Predicate<HTTPMatchRequestBuilder> predicate);
  public A withMatch(List<HTTPMatchRequest> match);
  public A withMatch(io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequest... match);
  public Boolean hasMatch();
  public HTTPRouteFluent.MatchNested<A> addNewMatch();
  public HTTPRouteFluent.MatchNested<A> addNewMatchLike(HTTPMatchRequest item);
  public HTTPRouteFluent.MatchNested<A> setNewMatchLike(Integer index,HTTPMatchRequest item);
  public HTTPRouteFluent.MatchNested<A> editMatch(Integer index);
  public HTTPRouteFluent.MatchNested<A> editFirstMatch();
  public HTTPRouteFluent.MatchNested<A> editLastMatch();
  public HTTPRouteFluent.MatchNested<A> editMatchingMatch(Predicate<HTTPMatchRequestBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMirror instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getMirror();
  public Destination buildMirror();
  public A withMirror(Destination mirror);
  public Boolean hasMirror();
  public HTTPRouteFluent.MirrorNested<A> withNewMirror();
  public HTTPRouteFluent.MirrorNested<A> withNewMirrorLike(Destination item);
  public HTTPRouteFluent.MirrorNested<A> editMirror();
  public HTTPRouteFluent.MirrorNested<A> editOrNewMirror();
  public HTTPRouteFluent.MirrorNested<A> editOrNewMirrorLike(Destination item);
  public Integer getMirrorPercent();
  public A withMirrorPercent(Integer mirrorPercent);
  public Boolean hasMirrorPercent();
  
  /**
   * This method has been deprecated, please use method buildMirrorPercentage instead.
   * @return The buildable object.
   */
  @Deprecated
  public Percent getMirrorPercentage();
  public Percent buildMirrorPercentage();
  public A withMirrorPercentage(Percent mirrorPercentage);
  public Boolean hasMirrorPercentage();
  public A withNewMirrorPercentage(Double value);
  public HTTPRouteFluent.MirrorPercentageNested<A> withNewMirrorPercentage();
  public HTTPRouteFluent.MirrorPercentageNested<A> withNewMirrorPercentageLike(Percent item);
  public HTTPRouteFluent.MirrorPercentageNested<A> editMirrorPercentage();
  public HTTPRouteFluent.MirrorPercentageNested<A> editOrNewMirrorPercentage();
  public HTTPRouteFluent.MirrorPercentageNested<A> editOrNewMirrorPercentageLike(Percent item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildRedirect instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRedirect getRedirect();
  public HTTPRedirect buildRedirect();
  public A withRedirect(HTTPRedirect redirect);
  public Boolean hasRedirect();
  public HTTPRouteFluent.RedirectNested<A> withNewRedirect();
  public HTTPRouteFluent.RedirectNested<A> withNewRedirectLike(HTTPRedirect item);
  public HTTPRouteFluent.RedirectNested<A> editRedirect();
  public HTTPRouteFluent.RedirectNested<A> editOrNewRedirect();
  public HTTPRouteFluent.RedirectNested<A> editOrNewRedirectLike(HTTPRedirect item);
  
  /**
   * This method has been deprecated, please use method buildRetries instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRetry getRetries();
  public HTTPRetry buildRetries();
  public A withRetries(HTTPRetry retries);
  public Boolean hasRetries();
  public A withNewRetries(Integer attempts,String perTryTimeout,String retryOn,Boolean retryRemoteLocalities);
  public HTTPRouteFluent.RetriesNested<A> withNewRetries();
  public HTTPRouteFluent.RetriesNested<A> withNewRetriesLike(HTTPRetry item);
  public HTTPRouteFluent.RetriesNested<A> editRetries();
  public HTTPRouteFluent.RetriesNested<A> editOrNewRetries();
  public HTTPRouteFluent.RetriesNested<A> editOrNewRetriesLike(HTTPRetry item);
  
  /**
   * This method has been deprecated, please use method buildRewrite instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRewrite getRewrite();
  public HTTPRewrite buildRewrite();
  public A withRewrite(HTTPRewrite rewrite);
  public Boolean hasRewrite();
  public A withNewRewrite(String authority,String uri);
  public HTTPRouteFluent.RewriteNested<A> withNewRewrite();
  public HTTPRouteFluent.RewriteNested<A> withNewRewriteLike(HTTPRewrite item);
  public HTTPRouteFluent.RewriteNested<A> editRewrite();
  public HTTPRouteFluent.RewriteNested<A> editOrNewRewrite();
  public HTTPRouteFluent.RewriteNested<A> editOrNewRewriteLike(HTTPRewrite item);
  public A addToRoute(Integer index,HTTPRouteDestination item);
  public A setToRoute(Integer index,HTTPRouteDestination item);
  public A addToRoute(io.fabric8.istio.api.networking.v1alpha3.HTTPRouteDestination... items);
  public A addAllToRoute(Collection<HTTPRouteDestination> items);
  public A removeFromRoute(io.fabric8.istio.api.networking.v1alpha3.HTTPRouteDestination... items);
  public A removeAllFromRoute(Collection<HTTPRouteDestination> items);
  public A removeMatchingFromRoute(Predicate<HTTPRouteDestinationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRoute instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRouteDestination> getRoute();
  public List<HTTPRouteDestination> buildRoute();
  public HTTPRouteDestination buildRoute(Integer index);
  public HTTPRouteDestination buildFirstRoute();
  public HTTPRouteDestination buildLastRoute();
  public HTTPRouteDestination buildMatchingRoute(Predicate<HTTPRouteDestinationBuilder> predicate);
  public Boolean hasMatchingRoute(Predicate<HTTPRouteDestinationBuilder> predicate);
  public A withRoute(List<HTTPRouteDestination> route);
  public A withRoute(io.fabric8.istio.api.networking.v1alpha3.HTTPRouteDestination... route);
  public Boolean hasRoute();
  public HTTPRouteFluent.RouteNested<A> addNewRoute();
  public HTTPRouteFluent.RouteNested<A> addNewRouteLike(HTTPRouteDestination item);
  public HTTPRouteFluent.RouteNested<A> setNewRouteLike(Integer index,HTTPRouteDestination item);
  public HTTPRouteFluent.RouteNested<A> editRoute(Integer index);
  public HTTPRouteFluent.RouteNested<A> editFirstRoute();
  public HTTPRouteFluent.RouteNested<A> editLastRoute();
  public HTTPRouteFluent.RouteNested<A> editMatchingRoute(Predicate<HTTPRouteDestinationBuilder> predicate);
  public String getTimeout();
  public A withTimeout(String timeout);
  public Boolean hasTimeout();
  public interface CorsPolicyNested<N> extends Nested<N>,CorsPolicyFluent<HTTPRouteFluent.CorsPolicyNested<N>>{
    public N and();
    public N endCorsPolicy();
    
  }
  public interface DelegateNested<N> extends Nested<N>,DelegateFluent<HTTPRouteFluent.DelegateNested<N>>{
    public N and();
    public N endDelegate();
    
  }
  public interface FaultNested<N> extends Nested<N>,HTTPFaultInjectionFluent<HTTPRouteFluent.FaultNested<N>>{
    public N and();
    public N endFault();
    
  }
  public interface HeadersNested<N> extends Nested<N>,HeadersFluent<HTTPRouteFluent.HeadersNested<N>>{
    public N and();
    public N endHeaders();
    
  }
  public interface MatchNested<N> extends Nested<N>,HTTPMatchRequestFluent<HTTPRouteFluent.MatchNested<N>>{
    public N and();
    public N endMatch();
    
  }
  public interface MirrorNested<N> extends Nested<N>,DestinationFluent<HTTPRouteFluent.MirrorNested<N>>{
    public N and();
    public N endMirror();
    
  }
  public interface MirrorPercentageNested<N> extends Nested<N>,PercentFluent<HTTPRouteFluent.MirrorPercentageNested<N>>{
    public N and();
    public N endMirrorPercentage();
    
  }
  public interface RedirectNested<N> extends Nested<N>,HTTPRedirectFluent<HTTPRouteFluent.RedirectNested<N>>{
    public N and();
    public N endRedirect();
    
  }
  public interface RetriesNested<N> extends Nested<N>,HTTPRetryFluent<HTTPRouteFluent.RetriesNested<N>>{
    public N and();
    public N endRetries();
    
  }
  public interface RewriteNested<N> extends Nested<N>,HTTPRewriteFluent<HTTPRouteFluent.RewriteNested<N>>{
    public N and();
    public N endRewrite();
    
  }
  public interface RouteNested<N> extends Nested<N>,HTTPRouteDestinationFluent<HTTPRouteFluent.RouteNested<N>>{
    public N and();
    public N endRoute();
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPRouteFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Double;
import java.util.Collection;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import java.util.Iterator;
import java.lang.Integer;

 /**
  * Generated
  */
public interface HTTPRouteFluent<A extends HTTPRouteFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCorsPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public CorsPolicy getCorsPolicy();
  public CorsPolicy buildCorsPolicy();
  public A withCorsPolicy(CorsPolicy corsPolicy);
  public Boolean hasCorsPolicy();
  public HTTPRouteFluent.CorsPolicyNested<A> withNewCorsPolicy();
  public HTTPRouteFluent.CorsPolicyNested<A> withNewCorsPolicyLike(CorsPolicy item);
  public HTTPRouteFluent.CorsPolicyNested<A> editCorsPolicy();
  public HTTPRouteFluent.CorsPolicyNested<A> editOrNewCorsPolicy();
  public HTTPRouteFluent.CorsPolicyNested<A> editOrNewCorsPolicyLike(CorsPolicy item);
  
  /**
   * This method has been deprecated, please use method buildDelegate instead.
   * @return The buildable object.
   */
  @Deprecated
  public Delegate getDelegate();
  public Delegate buildDelegate();
  public A withDelegate(Delegate delegate);
  public Boolean hasDelegate();
  public A withNewDelegate(String name,String namespace);
  public HTTPRouteFluent.DelegateNested<A> withNewDelegate();
  public HTTPRouteFluent.DelegateNested<A> withNewDelegateLike(Delegate item);
  public HTTPRouteFluent.DelegateNested<A> editDelegate();
  public HTTPRouteFluent.DelegateNested<A> editOrNewDelegate();
  public HTTPRouteFluent.DelegateNested<A> editOrNewDelegateLike(Delegate item);
  
  /**
   * This method has been deprecated, please use method buildFault instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPFaultInjection getFault();
  public HTTPFaultInjection buildFault();
  public A withFault(HTTPFaultInjection fault);
  public Boolean hasFault();
  public HTTPRouteFluent.FaultNested<A> withNewFault();
  public HTTPRouteFluent.FaultNested<A> withNewFaultLike(HTTPFaultInjection item);
  public HTTPRouteFluent.FaultNested<A> editFault();
  public HTTPRouteFluent.FaultNested<A> editOrNewFault();
  public HTTPRouteFluent.FaultNested<A> editOrNewFaultLike(HTTPFaultInjection item);
  
  /**
   * This method has been deprecated, please use method buildHeaders instead.
   * @return The buildable object.
   */
  @Deprecated
  public Headers getHeaders();
  public Headers buildHeaders();
  public A withHeaders(Headers headers);
  public Boolean hasHeaders();
  public HTTPRouteFluent.HeadersNested<A> withNewHeaders();
  public HTTPRouteFluent.HeadersNested<A> withNewHeadersLike(Headers item);
  public HTTPRouteFluent.HeadersNested<A> editHeaders();
  public HTTPRouteFluent.HeadersNested<A> editOrNewHeaders();
  public HTTPRouteFluent.HeadersNested<A> editOrNewHeadersLike(Headers item);
  public A addToMatch(int index,HTTPMatchRequest item);
  public A setToMatch(int index,HTTPMatchRequest item);
  public A addToMatch(io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequest... items);
  public A addAllToMatch(Collection<HTTPMatchRequest> items);
  public A removeFromMatch(io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequest... items);
  public A removeAllFromMatch(Collection<HTTPMatchRequest> items);
  public A removeMatchingFromMatch(Predicate<HTTPMatchRequestBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMatch instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPMatchRequest> getMatch();
  public List<HTTPMatchRequest> buildMatch();
  public HTTPMatchRequest buildMatch(int index);
  public HTTPMatchRequest buildFirstMatch();
  public HTTPMatchRequest buildLastMatch();
  public HTTPMatchRequest buildMatchingMatch(Predicate<HTTPMatchRequestBuilder> predicate);
  public Boolean hasMatchingMatch(Predicate<HTTPMatchRequestBuilder> predicate);
  public A withMatch(List<HTTPMatchRequest> match);
  public A withMatch(io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequest... match);
  public Boolean hasMatch();
  public HTTPRouteFluent.MatchNested<A> addNewMatch();
  public HTTPRouteFluent.MatchNested<A> addNewMatchLike(HTTPMatchRequest item);
  public HTTPRouteFluent.MatchNested<A> setNewMatchLike(int index,HTTPMatchRequest item);
  public HTTPRouteFluent.MatchNested<A> editMatch(int index);
  public HTTPRouteFluent.MatchNested<A> editFirstMatch();
  public HTTPRouteFluent.MatchNested<A> editLastMatch();
  public HTTPRouteFluent.MatchNested<A> editMatchingMatch(Predicate<HTTPMatchRequestBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMirror instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getMirror();
  public Destination buildMirror();
  public A withMirror(Destination mirror);
  public Boolean hasMirror();
  public HTTPRouteFluent.MirrorNested<A> withNewMirror();
  public HTTPRouteFluent.MirrorNested<A> withNewMirrorLike(Destination item);
  public HTTPRouteFluent.MirrorNested<A> editMirror();
  public HTTPRouteFluent.MirrorNested<A> editOrNewMirror();
  public HTTPRouteFluent.MirrorNested<A> editOrNewMirrorLike(Destination item);
  public Integer getMirrorPercent();
  public A withMirrorPercent(Integer mirrorPercent);
  public Boolean hasMirrorPercent();
  
  /**
   * This method has been deprecated, please use method buildMirrorPercentage instead.
   * @return The buildable object.
   */
  @Deprecated
  public Percent getMirrorPercentage();
  public Percent buildMirrorPercentage();
  public A withMirrorPercentage(Percent mirrorPercentage);
  public Boolean hasMirrorPercentage();
  public A withNewMirrorPercentage(Double value);
  public HTTPRouteFluent.MirrorPercentageNested<A> withNewMirrorPercentage();
  public HTTPRouteFluent.MirrorPercentageNested<A> withNewMirrorPercentageLike(Percent item);
  public HTTPRouteFluent.MirrorPercentageNested<A> editMirrorPercentage();
  public HTTPRouteFluent.MirrorPercentageNested<A> editOrNewMirrorPercentage();
  public HTTPRouteFluent.MirrorPercentageNested<A> editOrNewMirrorPercentageLike(Percent item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  
  /**
   * This method has been deprecated, please use method buildRedirect instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRedirect getRedirect();
  public HTTPRedirect buildRedirect();
  public A withRedirect(HTTPRedirect redirect);
  public Boolean hasRedirect();
  public HTTPRouteFluent.RedirectNested<A> withNewRedirect();
  public HTTPRouteFluent.RedirectNested<A> withNewRedirectLike(HTTPRedirect item);
  public HTTPRouteFluent.RedirectNested<A> editRedirect();
  public HTTPRouteFluent.RedirectNested<A> editOrNewRedirect();
  public HTTPRouteFluent.RedirectNested<A> editOrNewRedirectLike(HTTPRedirect item);
  
  /**
   * This method has been deprecated, please use method buildRetries instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRetry getRetries();
  public HTTPRetry buildRetries();
  public A withRetries(HTTPRetry retries);
  public Boolean hasRetries();
  public A withNewRetries(Integer attempts,String perTryTimeout,String retryOn,Boolean retryRemoteLocalities);
  public HTTPRouteFluent.RetriesNested<A> withNewRetries();
  public HTTPRouteFluent.RetriesNested<A> withNewRetriesLike(HTTPRetry item);
  public HTTPRouteFluent.RetriesNested<A> editRetries();
  public HTTPRouteFluent.RetriesNested<A> editOrNewRetries();
  public HTTPRouteFluent.RetriesNested<A> editOrNewRetriesLike(HTTPRetry item);
  
  /**
   * This method has been deprecated, please use method buildRewrite instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRewrite getRewrite();
  public HTTPRewrite buildRewrite();
  public A withRewrite(HTTPRewrite rewrite);
  public Boolean hasRewrite();
  public A withNewRewrite(String authority,String uri);
  public HTTPRouteFluent.RewriteNested<A> withNewRewrite();
  public HTTPRouteFluent.RewriteNested<A> withNewRewriteLike(HTTPRewrite item);
  public HTTPRouteFluent.RewriteNested<A> editRewrite();
  public HTTPRouteFluent.RewriteNested<A> editOrNewRewrite();
  public HTTPRouteFluent.RewriteNested<A> editOrNewRewriteLike(HTTPRewrite item);
  public A addToRoute(int index,HTTPRouteDestination item);
  public A setToRoute(int index,HTTPRouteDestination item);
  public A addToRoute(io.fabric8.istio.api.networking.v1alpha3.HTTPRouteDestination... items);
  public A addAllToRoute(Collection<HTTPRouteDestination> items);
  public A removeFromRoute(io.fabric8.istio.api.networking.v1alpha3.HTTPRouteDestination... items);
  public A removeAllFromRoute(Collection<HTTPRouteDestination> items);
  public A removeMatchingFromRoute(Predicate<HTTPRouteDestinationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRoute instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRouteDestination> getRoute();
  public List<HTTPRouteDestination> buildRoute();
  public HTTPRouteDestination buildRoute(int index);
  public HTTPRouteDestination buildFirstRoute();
  public HTTPRouteDestination buildLastRoute();
  public HTTPRouteDestination buildMatchingRoute(Predicate<HTTPRouteDestinationBuilder> predicate);
  public Boolean hasMatchingRoute(Predicate<HTTPRouteDestinationBuilder> predicate);
  public A withRoute(List<HTTPRouteDestination> route);
  public A withRoute(io.fabric8.istio.api.networking.v1alpha3.HTTPRouteDestination... route);
  public Boolean hasRoute();
  public HTTPRouteFluent.RouteNested<A> addNewRoute();
  public HTTPRouteFluent.RouteNested<A> addNewRouteLike(HTTPRouteDestination item);
  public HTTPRouteFluent.RouteNested<A> setNewRouteLike(int index,HTTPRouteDestination item);
  public HTTPRouteFluent.RouteNested<A> editRoute(int index);
  public HTTPRouteFluent.RouteNested<A> editFirstRoute();
  public HTTPRouteFluent.RouteNested<A> editLastRoute();
  public HTTPRouteFluent.RouteNested<A> editMatchingRoute(Predicate<HTTPRouteDestinationBuilder> predicate);
  public String getTimeout();
  public A withTimeout(String timeout);
  public Boolean hasTimeout();
  public interface CorsPolicyNested<N> extends Nested<N>,CorsPolicyFluent<HTTPRouteFluent.CorsPolicyNested<N>>{
    public N and();
    public N endCorsPolicy();
    
  }
  public interface DelegateNested<N> extends Nested<N>,DelegateFluent<HTTPRouteFluent.DelegateNested<N>>{
    public N and();
    public N endDelegate();
    
  }
  public interface FaultNested<N> extends Nested<N>,HTTPFaultInjectionFluent<HTTPRouteFluent.FaultNested<N>>{
    public N and();
    public N endFault();
    
  }
  public interface HeadersNested<N> extends Nested<N>,HeadersFluent<HTTPRouteFluent.HeadersNested<N>>{
    public N and();
    public N endHeaders();
    
  }
  public interface MatchNested<N> extends Nested<N>,HTTPMatchRequestFluent<HTTPRouteFluent.MatchNested<N>>{
    public N and();
    public N endMatch();
    
  }
  public interface MirrorNested<N> extends Nested<N>,DestinationFluent<HTTPRouteFluent.MirrorNested<N>>{
    public N and();
    public N endMirror();
    
  }
  public interface MirrorPercentageNested<N> extends Nested<N>,PercentFluent<HTTPRouteFluent.MirrorPercentageNested<N>>{
    public N and();
    public N endMirrorPercentage();
    
  }
  public interface RedirectNested<N> extends Nested<N>,HTTPRedirectFluent<HTTPRouteFluent.RedirectNested<N>>{
    public N and();
    public N endRedirect();
    
  }
  public interface RetriesNested<N> extends Nested<N>,HTTPRetryFluent<HTTPRouteFluent.RetriesNested<N>>{
    public N and();
    public N endRetries();
    
  }
  public interface RewriteNested<N> extends Nested<N>,HTTPRewriteFluent<HTTPRouteFluent.RewriteNested<N>>{
    public N and();
    public N endRewrite();
    
  }
  public interface RouteNested<N> extends Nested<N>,HTTPRouteDestinationFluent<HTTPRouteFluent.RouteNested<N>>{
    public N and();
    public N endRoute();
    
  }
  
}
